@@ -1,12 +1,12 @@
-﻿(function ($, document, window) {
+﻿define(['jQuery'], function ($) {
 
     function resetTuner(page, id) {
 
         var message = Globalize.translate('MessageConfirmResetTuner');
 
-        Dashboard.confirm(message, Globalize.translate('HeaderResetTuner'), function (confirmResult) {
+        require(['confirm'], function (confirm) {
 
-            if (confirmResult) {
+            confirm(message, Globalize.translate('HeaderResetTuner')).then(function () {
 
                 Dashboard.showLoadingMsg();
 
@@ -16,7 +16,7 @@
 
                     reload(page);
                 });
-            }
+            });
         });
     }
 
@@ -74,7 +74,11 @@
                 html += '</div>';
 
                 html += '</paper-item-body>';
-                html += '<paper-icon-button icon="refresh" data-tunerid="' + tuner.Id + '" title="' + Globalize.translate('ButtonResetTuner') + '" class="btnResetTuner"></paper-icon-button>';
+
+                if (tuner.CanReset) {
+                    html += '<paper-icon-button icon="refresh" data-tunerid="' + tuner.Id + '" title="' + Globalize.translate('ButtonResetTuner') + '" class="btnResetTuner"></paper-icon-button>';
+                }
+
                 html += '</paper-icon-item>';
             }
 
@@ -160,7 +164,7 @@
             $('.servicesSection', page).hide();
         }
 
-        $('.servicesList', page).html(servicesToDisplay.map(getServiceHtml).join('')).trigger('create');
+        $('.servicesList', page).html(servicesToDisplay.map(getServiceHtml).join(''));
 
         var tuners = [];
         for (var i = 0, length = liveTvInfo.Services.length; i < length; i++) {
@@ -201,7 +205,7 @@
                 html += '<paper-item-body two-line>';
                 html += '<a class="clearLink" href="' + href + '">';
                 html += '<div>';
-                html += getTunerName(device.Type);
+                html += device.FriendlyName || getTunerName(device.Type);
                 html += '</div>';
 
                 html += '<div secondary>';
@@ -231,9 +235,9 @@
 
         var message = Globalize.translate('MessageConfirmDeleteTunerDevice');
 
-        Dashboard.confirm(message, Globalize.translate('HeaderDeleteDevice'), function (confirmResult) {
+        require(['confirm'], function (confirm) {
 
-            if (confirmResult) {
+            confirm(message, Globalize.translate('HeaderDeleteDevice')).then(function () {
 
                 Dashboard.showLoadingMsg();
 
@@ -247,7 +251,7 @@
 
                     reload(page);
                 });
-            }
+            });
         });
     }
 
@@ -333,9 +337,9 @@
 
         var message = Globalize.translate('MessageConfirmDeleteGuideProvider');
 
-        Dashboard.confirm(message, Globalize.translate('HeaderDeleteProvider'), function (confirmResult) {
+        require(['confirm'], function (confirm) {
 
-            if (confirmResult) {
+            confirm(message, Globalize.translate('HeaderDeleteProvider')).then(function () {
 
                 Dashboard.showLoadingMsg();
 
@@ -353,7 +357,7 @@
 
                     reload(page);
                 });
-            }
+            });
         });
     }
 
@@ -367,6 +371,8 @@
                 return 'M3U Playlist';
             case 'hdhomerun':
                 return 'HDHomerun';
+            case 'satip':
+                return 'DVB';
             default:
                 return 'Unknown';
         }
@@ -421,9 +427,9 @@
             id: 'other'
         });
 
-        require(['actionsheet'], function () {
+        require(['actionsheet'], function (actionsheet) {
 
-            ActionSheetElement.show({
+            actionsheet.show({
                 items: menuItems,
                 positionTo: button,
                 callback: function (id) {
@@ -445,6 +451,11 @@
 
         var menuItems = [];
 
+        //menuItems.push({
+        //    name: getTunerName('satip'),
+        //    id: 'satip'
+        //});
+
         menuItems.push({
             name: 'HDHomerun',
             id: 'hdhomerun'
@@ -460,9 +471,9 @@
             id: 'other'
         });
 
-        require(['actionsheet'], function () {
+        require(['actionsheet'], function (actionsheet) {
 
-            ActionSheetElement.show({
+            actionsheet.show({
                 items: menuItems,
                 positionTo: button,
                 callback: function (id) {
@@ -521,4 +532,4 @@
 
     });
 
-})(jQuery, document, window);
+});
