@@ -1,4 +1,4 @@
-﻿(function ($, window, document) {
+﻿define(['jQuery'], function ($) {
 
     function renderViews(page, user, result) {
 
@@ -154,6 +154,13 @@
         });
     }
 
+    function displayPreferencesKey() {
+        if (AppInfo.isNativeApp) {
+            return 'Emby Mobile';
+        }
+
+        return 'webclient';
+    }
     function saveUser(page, user, displayPreferences) {
 
         user.Configuration.DisplayCollectionsView = page.querySelector('.chkDisplayCollectionView').checked;
@@ -200,7 +207,7 @@
         displayPreferences.CustomPrefs.home2 = $('#selectHomeSection3', page).val();
         displayPreferences.CustomPrefs.home3 = $('#selectHomeSection4', page).val();
 
-        return ApiClient.updateDisplayPreferences('home', displayPreferences, user.Id, AppSettings.displayPreferencesKey()).then(function () {
+        return ApiClient.updateDisplayPreferences('home', displayPreferences, user.Id, displayPreferencesKey()).then(function () {
 
             return ApiClient.updateUserConfiguration(user.Id, user.Configuration);
         });
@@ -218,13 +225,15 @@
 
         ApiClient.getUser(userId).then(function (user) {
 
-            ApiClient.getDisplayPreferences('home', user.Id, AppSettings.displayPreferencesKey()).then(function (displayPreferences) {
+            ApiClient.getDisplayPreferences('home', user.Id, displayPreferencesKey()).then(function (displayPreferences) {
 
                 saveUser(page, user, displayPreferences).then(function () {
 
                     Dashboard.hideLoadingMsg();
                     if (!AppInfo.enableAutoSave) {
-                        Dashboard.alert(Globalize.translate('SettingsSaved'));
+                        require(['toast'], function (toast) {
+                            toast(Globalize.translate('SettingsSaved'));
+                        });
                     }
 
                 }, function () {
@@ -306,7 +315,7 @@
 
         ApiClient.getUser(userId).then(function (user) {
 
-            ApiClient.getDisplayPreferences('home', user.Id, AppSettings.displayPreferencesKey()).then(function (result) {
+            ApiClient.getDisplayPreferences('home', user.Id, displayPreferencesKey()).then(function (result) {
 
                 loadForm(page, user, result);
 
@@ -317,10 +326,10 @@
     pageIdOn('pagebeforehide', "homeScreenPreferencesPage", function () {
 
         var page = this;
-        
+
         if (AppInfo.enableAutoSave) {
             save(page);
         }
     });
 
-})(jQuery, window, document);
\ No newline at end of file
+});
\ No newline at end of file
