@@ -1,6 +1,6 @@
-﻿(function ($, document) {
+﻿define([], function () {
 
-    function loadUpcoming(page) {
+    function loadUpcoming(context, params) {
 
         Dashboard.showLoadingMsg();
 
@@ -17,25 +17,22 @@
             EnableImageTypes: "Primary,Backdrop,Banner,Thumb"
         };
 
-        query.ParentId = LibraryMenu.getTopParentId();
+        query.ParentId = params.topParentId;
 
         ApiClient.getJSON(ApiClient.getUrl("Shows/Upcoming", query)).then(function (result) {
 
             var items = result.Items;
 
             if (items.length) {
-                page.querySelector('.noItemsMessage').style.display = 'none';
+                context.querySelector('.noItemsMessage').style.display = 'none';
             } else {
-                page.querySelector('.noItemsMessage').style.display = 'block';
+                context.querySelector('.noItemsMessage').style.display = 'block';
             }
 
-            var elem = page.querySelector('#upcomingItems');
+            var elem = context.querySelector('#upcomingItems');
             renderUpcoming(elem, items);
 
             Dashboard.hideLoadingMsg();
-
-            LibraryBrowser.setLastRefreshed(page);
-
         });
     }
 
@@ -123,11 +120,13 @@
         ImageLoader.lazyChildren(elem);
     }
 
-    window.TvPage.renderUpcomingTab = function (page, tabContent) {
+    return function (view, params, tabContent) {
 
-        if (LibraryBrowser.needsRefresh(tabContent)) {
-            loadUpcoming(tabContent);
-        }
+        var self = this;
+
+        self.renderTab = function () {
+
+            loadUpcoming(tabContent, params);
+        };
     };
-
-})(jQuery, document);
\ No newline at end of file
+});
\ No newline at end of file
